# Welcome to Project Owl

Owl is a high level object oriented library for computer vision, machine learning and data processing.

The goal is to make it easy to prototype and productionize application easier.